@@ -13,6 +13,8 @@
 #' @param vegtable An object of class [vegtable-class].
 #' @param releves A data frame including plot observations to be added into
 #'     `vegtable`.
+#' @param value A data frame containing new plot observations. I is passed to
+#'     parameter 'releves' by the replace method.
 #' @param header A data frame (optional) including header information for plots.
 #' @param abundance A character value (or vector of length 2) indicating the
 #'     names of abundance variable in `vegtable`.
@@ -47,17 +49,20 @@ setGeneric("add_releves",
 #' 
 #' @aliases add_releves,vegtable,data.frame-method
 #' 
-setMethod("add_releves", signature(vegtable="vegtable", releves="data.frame"),
+setMethod("add_releves", signature(vegtable = "vegtable",
+				releves = "data.frame"),
 		function(vegtable, releves, header, abundance, split_string,
-				usage_ids=FALSE, layers=FALSE, layers_var, format="crosstable",
-				preserve_ids=FALSE, ...) {
+				usage_ids = FALSE, layers = FALSE, layers_var,
+				format = "crosstable", preserve_ids = FALSE, ...) {
 			# Step 1: Make database list, if necessary
 			format <- pmatch(tolower(format), c("crosstable","databaselist"))
 			if(!format %in% c(1:2))
 				stop("Non valid value for 'format'.")
 			if(format == 1) {
 				releves <- cross2db(releves, layers, ...)
-				colnames(releves)[1:2] <- c("ReleveID", "TaxonUsageID")
+				colnames(releves) <- replace_x(x = colnames(releves),
+						old = c("plot", "species"),
+						new = c("ReleveID", "TaxonUsageID"))
 			}
 			message(paste("Imported records:", nrow(releves)))
 			# Step 1: Recognize species
@@ -67,7 +72,8 @@ setMethod("add_releves", signature(vegtable="vegtable", releves="data.frame"),
 			if(!usage_ids & format == 2) {
 				if(!"TaxonName" %in% colnames(releves))
 					stop(paste("Colum 'TaxonName' is mandatory in 'releves'",
-									"provided as database list."))
+									"provided as database list",
+									"with the option 'usage_ids = FALSE'."))
 				releves$TaxonUsageID <- match_names(releves$TaxonName,
 						vegtable)$TaxonUsageID
 				# delete column TaxonName
@@ -75,25 +81,37 @@ setMethod("add_releves", signature(vegtable="vegtable", releves="data.frame"),
 			}
 			message(paste("Matched taxon usage names:",
 							length(unique(releves$TaxonUsageID))))
+			# TODO: Action needed if unmatched taxon names
 			# Step 3: Check layers, if necessary
+			# TODO: next code have to be tested for 'format = "databaselist"'
 			if(layers) {
-				colnames(releves)[3] <- layers_var
-				if(!layers_var %in% colnames(vegtable@samples))
-					stop("Variable 'layers_var' not occurring in 'vegtable'")
+				if(format == 1)
+					colnames(releves) <- replace_x(x = colnames(releves),
+							old = "layers", new = layers_var)
+				# Add layers variables 
+				if(layers & (!layers_var %in% colnames(vegtable@samples))) {
+					vegtable@samples[ , layers_var] <- NA
+					class(vegtable@samples[ , layers_var]) <- class(releves[ ,
+									layers_var])
+				}
 				if(is.factor(vegtable@samples[,layers_var]))
 					releves[,layers_var] <- factor(paste(releves[,layers_var]),
 							levels(vegtable@samples[,layers_var])) else
-					class(releves[,layers_var]) <- class(vegtable@samples[,
+					class(releves[ , layers_var]) <- class(vegtable@samples[ ,
 									layers_var])
-				if(any(!releves[,layers_var] %in%
-								vegtable@layers[[layers_var]][,layers_var]))
+				# Check for the existence of layers in slot layers
+				# Otherwise warn about missing table
+				if((layers_var %in% names(vegtable@layers)) &
+						(any(!releves[ , layers_var] %in%
+											vegtable@layers[[layers_var]][ ,
+													layers_var])))
 					stop("Values of 'layers_var' missing in 'vegtable'")
+				if(!layers_var %in% names(vegtable@layers))
+					warning(paste("There is no table in slot 'layers' for",
+									"'layers_var'."))
 			}
 			# Step 4: Reformat abundance (only for cross tables)
 			if(format == 1) {
-				if(any(!abundance %in% colnames(vegtable@samples)))
-					stop(paste("Some values of 'abundance' are not yet",
-									"included in 'vegtable'."))
 				if(length(abundance) == 2) {
 					cover <- stri_split_fixed(releves[,ncol(releves)],
 							split_string)
@@ -102,10 +120,20 @@ setMethod("add_releves", signature(vegtable="vegtable", releves="data.frame"),
 								return(x)
 							})
 					cover <- do.call(rbind, cover)
-					releves[,ncol(releves)] <- cover[,1]
-					releves[,ncol(releves) + 1] <- cover[,2]
-					colnames(releves)[ncol(releves) - c(1,0)] <- abundance
+					releves[ , ncol(releves)] <- cover[ , 1]
+					releves[ , ncol(releves) + 1] <- cover[ , 2]
+					colnames(releves)[ncol(releves) - c(1, 0)] <- abundance
 				} else colnames(releves)[ncol(releves)] <- abundance
+				# Add missing abundance columns
+				missing_ab <- abundance[!abundance %in%
+								colnames(vegtable@samples)]
+				if(length(missing_ab) > 0) {
+					for(i in missing_ab) {
+						vegtable@samples[ , i] <- NA
+						class(vegtable@samples[ , i]) <- class(releves[ , i])
+					}
+				}
+				# insert abundance
 				for(i in abundance) {
 					if(is.factor(vegtable@samples[,i]))
 						releves[,i] <- factor(paste(releves[,i]),
@@ -136,10 +164,12 @@ setMethod("add_releves", signature(vegtable="vegtable", releves="data.frame"),
 			} else header <- data.frame(ReleveID=unique(releves$ReleveID),
 						stringsAsFactors=FALSE)
 			# Step 6: Assembly vegtable
+			# TODO: Added cover is not testing for presence of coverconvert
 			if(!preserve_ids) {
 				old_ReleveID <- header$ReleveID
 				if(nrow(vegtable@header) > 0)
-					header$ReleveID <- max(vegtable$ReleveID) + 1:nrow(header) else
+					header$ReleveID <- max(vegtable$ReleveID) +
+							1:nrow(header) else
 					header$ReleveID <- 1:nrow(header)
 				releves$ReleveID <- header$ReleveID[match(releves$ReleveID,
 								old_ReleveID)]
@@ -165,7 +195,26 @@ setMethod("add_releves", signature(vegtable="vegtable", releves="data.frame"),
 				vegtable@samples <- do.call(rbind, list(vegtable@samples,
 								releves[,colnames(vegtable@samples)]))
 			} else vegtable@samples <- releves
-			message("DONE")
+			message("DONE!\n")
 			return(vegtable)
 		}
 )
+
+#' @rdname add_releves
+#' 
+#' @aliases add_releves<-
+#' 
+#' @exportMethod add_releves<-
+#' 
+setGeneric("add_releves<-", function(vegtable, ..., value)
+			standardGeneric("add_releves<-"))
+
+#' @rdname add_releves
+#' 
+#' @aliases add_releves<-,vegtable,data.frame-method
+#' 
+setReplaceMethod("add_releves", signature(vegtable = "vegtable",
+				value = "data.frame"),
+		function(vegtable, ..., value) {
+			return(add_releves(vegtable = vegtable, releves = value, ...))
+		})
